@@ -30,10 +30,6 @@ function init_banner() {
     var FRAME_BANNER_ID = "_wb_frame_top_banner";
     var bid;
 
-    if (wbinfo.is_embed) {
-        return;
-    }
-
     if (window.top != window.self) {
         return;
     }
@@ -123,23 +119,42 @@ function remove_event(name, func, object) {
     }
 }
 
-var detect_on_init = function(event) {
-    init_banner();
+function notify_top() {
+    if (window.parent != window.top) {
+        return;
+    }
 
-    remove_event("readystatechange", detect_on_init, document);
+    if (!window.WB_wombat_location) {
+        return;
+    }
+
+    if (typeof(window.WB_wombat_location.href) != "string") {
+        return;
+    }
+
+    window.parent.update_wb_url(window.WB_wombat_location.href,
+                                wbinfo.timestamp,
+                                wbinfo.is_live);
+
+    remove_event("readystatechange", notify_top, document);
 }
 
-add_event("readystatechange", detect_on_init, document);
-
-
-if (wbinfo.is_frame_mp && wbinfo.canon_url &&
-   (window.self == window.top) && (window.self.top == window.top) &&
-   window.location.href != wbinfo.canon_url) {
-    
-    window.location.replace(wbinfo.canon_url);
+if ((window.self == window.top) && wbinfo) {
+    if (wbinfo.canon_url && (window.location.href != wbinfo.canon_url) && wbinfo.mod != "bn_") {
+        // Auto-redirect to top frame
+        window.location.replace(wbinfo.canon_url);
+    } else {
+        // Init Banner (no frame or top frame)
+        add_event("readystatechange", init_banner, document);
+    }
+} else if (window.self != window.parent && window.parent.update_wb_url) {
+    add_event("readystatechange", notify_top, document);
 }
 
-return {'labels': labels,
-        'ts_to_date': ts_to_date};
+
+return {
+        'labels': labels,
+        'ts_to_date': ts_to_date
+       };
 
 })();
